@@ -185,10 +185,8 @@ class NumpyIndexedInterval(IndexedInterval):
         self._distance_to_node = distance_to_node_index
         self.min_node = min_node
         self._node_to_distance = node_to_distance_index
-
-
-
         self._nodes_in_interval_cache = None
+        self._sorted_nodes_in_interval_cache = None
 
     def length(self):
         return self._length
@@ -204,10 +202,19 @@ class NumpyIndexedInterval(IndexedInterval):
             return self._nodes_in_interval_cache
 
         # Hacky method to return nodes in interval
-        nodes = set(np.unique(self._distance_to_node))
+        nodes = set(np.unique(self._distance_to_node).astype(int))  
         self._nodes_in_interval_cache = nodes
         return nodes
 
+    def get_sorted_nodes_in_interval(self):
+        if self._sorted_nodes_in_interval_cache is not None:
+            return self._sorted_nodes_in_interval_cache
+
+        nodes = self._distance_to_node[np.nonzero(np.ediff1d(self._distance_to_node, to_begin=[-1]))]
+        self._sorted_nodes_in_interval_cache = nodes
+        return nodes
+
+
     @classmethod
     def from_interval(cls, interval):
         assert interval.start_position.offset == 0, "Currently only simple implementation supporting start offset=0"
@@ -294,7 +301,14 @@ class NumpyIndexedInterval(IndexedInterval):
     def get_nodes_between_offset(self, start, end):
         assert end <= len(self._distance_to_node)
         assert start >= 0
-        return np.unique(self._distance_to_node[start:end])
+        values = self._distance_to_node[start:end]
+        unique = values[:-1][values[1:]!=values[:-1]]
+        return np.concatenate((unique, values[-1:]))
+
+    def position_at_offset(self, offset):
+        node_offset = self.get_node_offset_at_offset(offset)
+        node = self._distance_to_node[offset]
+        return Position(node, node_offset)
 
     def get_subinterval(self, start, end):
         return NodeInterval(self.get_nodes_between_offset(start, end))
